@@ -6,7 +6,7 @@ package Mite::Role;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006006';
+our $VERSION   = '0.006007';
 
 use Path::Tiny;
 use B ();
@@ -70,10 +70,6 @@ sub BUILD {
     $reg->add_types( $library ) if $library;
 }
 
-sub skip_compiling {
-    return false;
-}
-
 sub _all_subs {
     my $self = shift;
     my $package = $self->name;
