@@ -7,11 +7,7 @@ use Mite::Miteception -all;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006006';
-
-sub skip_compiling {
-    return true;
-}
+our $VERSION   = '0.006007';
 
 sub inhale {
     my ( $class, $rolename, %args ) = @_;
